/**************************************************************************
*  This file is part of the TAL project (Tiny Abstraction Layer)
*
*  Copyright (c) 2013-2016 by Michael Fischer (www.emb4fun.de).
*  All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
***************************************************************************
*  History:
*
*  20.12.2013  mifi  First Version
**************************************************************************/
#if !defined(__TALBOARD_H__) && defined(USE_BOARD_EIR)
#define __TALBOARD_H__

/**************************************************************************
*  Includes
**************************************************************************/
#include "project.h"
#include "taltypes.h"

#include "at91sam7se512.h"

/**************************************************************************
*  Global Definitions
**************************************************************************/

/*
 * Defines for board and cpu name
 */
#define TAL_BOARD "ELEKTOR Internet Radio"
#define TAL_CPU   "AT91SAM7SE512"


/*
 * Check OSCILLATOR_CLOCK_FREQUENCY value, must be 18.432000 MHz
 */
#if (OSCILLATOR_CLOCK_FREQUENCY != 18432000)
   Error: OSCILLATOR_CLOCK_FREQUENCY must defined to 18432000 by the preprocessor;
#endif   


/*
 * With 3 bits of interrupt priority 8 levels are
 * available. Priority 7 is the highest one, 0 the lowest.
 */

#ifndef ETH_PRIO
#define ETH_PRIO        4
#endif

#ifndef USART0_PRIO
#define USART0_PRIO     1
#endif


/*
 * Oversampling mode
 *    TAL_TRUE : Oversampling by 8
 *    TAL_FALSE: Oversampling by 16
 */
 
#ifndef USART0_OVER_8
#define USART0_OVER_8   TAL_TRUE
#endif


/*
 * The EIR board support 2 LED
 */
typedef enum _tal_led_channel_
{
   TAL_LED_CHANNEL_1 = 0,
   TAL_LED_CHANNEL_2,
   
   /* TAL_LED_CHANNEL_MAX must be the last one */
   TAL_LED_CHANNEL_MAX
} TAL_LED_CHANNEL;

/*
 * LED name from the board itself
 */
#define LD1    TAL_LED_CHANNEL_1
#define LD2    TAL_LED_CHANNEL_2

/*
 * COM port used for the terminal
 */
#if !defined(TERM_COM_PORT)
#define TERM_COM_PORT   TAL_COM_PORT_1
#endif

/**************************************************************************
*  Macro Definitions
**************************************************************************/

/**************************************************************************
*  Functions Definitions
**************************************************************************/

TAL_RESULT tal_BoardEnableCOM1(void);
TAL_RESULT tal_BoardEnableCOM2(void);

#endif /* !__TALBOARD_H__ */

/*** EOF ***/
